/*
 * Copyright 2002 Henri Sivonen.
 *
 * The contents of this file are subject to the Artistic License.
 * You may not use this file except in compliance with the Artistic
 * License (which you should have received along with this file).
 */

package dualroids;

/**
 * Pumps the ship state to the server.
 *
 * @author Henri Sivonen, hsivonen@iki.fi
 */
public final class ShipStatePump implements Runnable {

    /**
     * The <code>SpaceShip</code> whose state this
     * <code>ShipStatePump</code> pumps.
     */
    private SpaceShip ship;

    /**
     * A <code>boolean</code> indicating whether the pumping should be
     * continued.
     */
    private boolean doLoop;

    /**
     * Contructs a new <code>ShipStatePump</code>.
     */
    public ShipStatePump() {
        this.ship = null;
        this.doLoop = true;
    }

    /**
     * Registers the ship whose state is to be pumped.
     * @param ship the ship whose state is to be pumped
     */
    public void registerShip(SpaceShip ship) {
        this.ship = ship;
    }

    /**
     * Tells the pump to stop.
     */
    public void stop() {
        this.doLoop = false;
    }

    /**
     * Starts the pump.
     */
    public void run() {
        while(this.doLoop) {
            if(this.ship != null) {
                this.ship.writeToConnector();
            }

            try {
                Thread.sleep(Server.MIN_ITERATION_INTERVAL);
            } catch(InterruptedException ie) {
                // carry on
            }
        }
    }
}
